@@ -1,5 +1,8 @@
 import re
 from typing import List
+from typing import Match
+from typing import Optional
+from typing import Pattern
 
 
 class SentenceTokenizer:
@@ -12,12 +15,20 @@ class SentenceTokenizer:
         re.compile(r"「.*?」"),
     ]
 
-    @staticmethod
-    def conv_period(item) -> str:
-        return item.group(0).replace(SentenceTokenizer.PERIOD, SentenceTokenizer.PERIOD_SPECIAL)
+    def __init__(
+        self,
+        period: Optional[str] = None,
+        patterns: Optional[List[Pattern[str]]] = None,
+    ) -> None:
 
-    def tokenize(self, document) -> List[str]:
-        for pattern in SentenceTokenizer.PATTERNS:
+        self._period = period or self.PERIOD
+        self._patterns = patterns or self.PATTERNS
+
+    def conv_period(self, item: Match) -> str:
+        return item.group(0).replace(self._period, SentenceTokenizer.PERIOD_SPECIAL)
+
+    def tokenize(self, document: str) -> List[str]:
+        for pattern in self._patterns:
             document = re.sub(pattern, self.conv_period, document)
 
         result = []
@@ -25,7 +36,7 @@ class SentenceTokenizer:
             line = line.rstrip()
             line = line.replace("\n", "")
             line = line.replace("\r", "")
-            line = line.replace("。", "。\n")
+            line = line.replace(f"{self._period}", f"{self._period}\n")
             sentences = line.split("\n")
 
             for sentence in sentences:
@@ -33,8 +44,7 @@ class SentenceTokenizer:
                     continue
 
                 period_special = SentenceTokenizer.PERIOD_SPECIAL
-                period = SentenceTokenizer.PERIOD
-                sentence = sentence.replace(period_special, period)
+                sentence = sentence.replace(period_special, self._period)
                 result.append(sentence)
 
         return result
